package com.xhkjedu.sapi.service.component;

import com.xhkjedu.sapi.mapper.component.UserComponentMapper;
import com.xhkjedu.sapi.model.component.TUserComponent;
import com.xhkjedu.sapi.vo.component.ComponentParams;
import com.xhkjedu.utils.N_Utils;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.util.List;
import java.util.Map;

/**
 * @Description：用户组件
 * @Author: WN
 * @Date: 2024/7/19 14:47:41
 **/
@Service
public class UserComponentService {
    @Resource
    private UserComponentMapper userComponentMapper;

    /*
     * @Description 保存用户组件
     * @Date 2024/7/19 14:58:07
     * @Author WN
     * @Param [componentParams]
     * @Return void
     **/
    @Transactional(rollbackFor = Exception.class)
    public void save(ComponentParams componentParams){
        int corder = 1;
        List<TUserComponent> userComponents = componentParams.getComponents();
        Integer userid = componentParams.getUserid();
        Integer timestamp = N_Utils.getSecondTimestamp();
        for(TUserComponent userComponent : userComponents){
            userComponent.setUserid(userid);
            userComponent.setCorder(corder);
            userComponent.setCreatetime(timestamp);
            corder++;
        }
        //保存前先删除已有组件
        userComponentMapper.deleteByUserid(userid);
        userComponentMapper.insertList(userComponents);
    }

    /*
     * @Description 获取用户组件
     * @Date 2024/7/19 15:07:26
     * @Author WN
     * @Param [userid]
     * @Return java.util.List<java.util.Map<java.lang.String,java.lang.Object>>
     **/
    public List<Map<String,Object>> listComponentsByUserid(Integer userid){
        return userComponentMapper.listComponentsByUserid(userid);
    }


}
